@@ -26,7 +26,18 @@ import nbconvert
 import nbformat
 from shutil import copyfile
 from copy import deepcopy
-import logging
+try:
+    from sphinx.util import logging
+    logger = logging.getLogger(__name__)
+except (ImportError, AttributeError):
+    import logging
+    logger = logging.getLogger(__name__)
+
+try:
+    warn = logger.warn
+except AttributeError:  # necessary for python 2.7
+    warn = logger.warning
+
 import subprocess as spr
 from docutils.parsers.rst import Directive
 from docutils.parsers.rst import directives
@@ -46,12 +57,10 @@ except ImportError:
         from ordereddict import OrderedDict
 
 
-__version__ = '0.3.0'
+__version__ = '0.3.1'
 
 __author__ = "Philipp Sommer"
 
-logger = logging.getLogger(__name__)
-
 if nbconvert.__version__ < '5.0':
     code_blocks = re.compile(r'\.\. code:: python\n(?s)(.+?)(?=\n\S+|$)')
     inner_code_blocks = re.compile(
@@ -459,8 +468,12 @@ logging.getLogger('py.warnings').setLevel(logging.ERROR)
             py_file = os.path.basename(self.py_file)
         else:
             py_file = self.py_file
+        try:
+            level = logger.logger.level
+        except AttributeError:
+            level = logger.level
         spr.call(['jupyter', 'nbconvert', '--to=python',
-                  '--output=' + py_file, '--log-level=%s' % logger.level,
+                  '--output=' + py_file, '--log-level=%s' % level,
                   self.outfile])
         with open(self.py_file) as f:
             py_content = f.read()
@@ -979,8 +992,8 @@ class LinkGalleriesDirective(Directive):
         try:
             inventory = self.env.intersphinx_named_inventory
         except AttributeError:
-            logger.warn('The %s directive requires the sphinx.ext.intersphinx '
-                        'extension!', self.name)
+            warn('The %s directive requires the sphinx.ext.intersphinx '
+                 'extension!', self.name)
             return [ret]
         for pkg_str in self.content:
             try:
@@ -1016,7 +1029,7 @@ class LinkGalleriesDirective(Directive):
                 try:
                     refs = inventory[pkg]['std:label']
                 except KeyError:
-                    logger.warn('Could not load the inventory of %s!', pkg)
+                    warn('Could not load the inventory of %s!', pkg)
                     continue
                 base_url = self.env.config.intersphinx_mapping[pkg][0]
                 if not base_url.endswith('/'):
